<?php

namespace Kylin\Property\Enums;

/**
 * 访客状态枚举
 */
enum VisitorStatus: string
{
    case INVITED = 'invited';
    case CHECKED_IN = 'checked_in';
    case CHECKED_OUT = 'checked_out';
    case EXPIRED = 'expired';
    case CANCELLED = 'cancelled';

    public function label(): string
    {
        return match ($this) {
            self::INVITED => '已邀请',
            self::CHECKED_IN => '已签到',
            self::CHECKED_OUT => '已签离',
            self::EXPIRED => '已过期',
            self::CANCELLED => '已取消',
        };
    }
}
