<?php

return [
    // 报修工单号前缀
    'repair_order_prefix' => 'WX',

    // 缴费账单号前缀
    'bill_order_prefix' => 'ZF',

    // 访客通行码前缀
    'visitor_pass_prefix' => 'VT',

    // 报修类型
    'repair_types' => [
        'water' => '水管漏水',
        'electric' => '电路故障',
        'door_window' => '门窗损坏',
        'elevator' => '电梯故障',
        'public_facility' => '公共设施',
        'other' => '其他',
    ],

    // 费用类型
    'fee_types' => [
        'property_fee' => '物业费',
        'water_fee' => '水费',
        'electric_fee' => '电费',
        'parking_fee' => '停车费',
        'gas_fee' => '燃气费',
        'other' => '其他',
    ],

    // 通知类型
    'notice_types' => [
        'water_cutoff' => '停水通知',
        'power_cutoff' => '停电通知',
        'elevator_maint' => '电梯维保',
        'gas_cutoff' => '停气通知',
        'property_notice' => '物业公告',
        'emergency' => '紧急通知',
        'meeting' => '会议通知',
        'other' => '其他',
    ],

    // 访客类型
    'visitor_types' => [
        'relative' => '亲属',
        'friend' => '朋友',
        'delivery' => '快递/外卖',
        'business' => '商务',
        'other' => '其他',
    ],
];
