<?php

namespace Kylin\Property\Enums;

/**
 * 物业用户角色枚举
 */
enum UserRole: string
{
    case ADMIN = 'admin';
    case MANAGER = 'manager';
    case STAFF = 'staff';
    case OWNER = 'owner';

    public function label(): string
    {
        return match ($this) {
            self::ADMIN => '超级管理员',
            self::MANAGER => '物业管理员',
            self::STAFF => '维修人员',
            self::OWNER => '业主',
        };
    }
}
