<?php

namespace Kylin\Property;

use Illuminate\Support\ServiceProvider;

/**
 * 物业管理系统服务提供者
 *
 * 提供物业管理核心功能：
 *  - 账单管理（BillStatus）
 *  - 维修工单（RepairType/RepairStatus）
 *  - 通知公告（NoticeType）
 *  - 访客管理（VisitorStatus）
 *  - 用户角色（UserRole）
 */
class PropertyServiceProvider extends ServiceProvider
{
    public function register(): void
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../config/kylin-property.php',
            'kylin-property'
        );
    }

    public function boot(): void
    {
        if ($this->app->runningInConsole()) {
            $this->publishes([
                __DIR__ . '/../config/kylin-property.php' => config_path('kylin-property.php'),
            ], 'kylin-property-config');
        }
    }
}
