<?php

namespace Kylin\Property\Enums;

/**
 * 通知类型枚举
 */
enum NoticeType: string
{
    case WATER_CUTOFF = 'water_cutoff';
    case POWER_CUTOFF = 'power_cutoff';
    case ELEVATOR_MAINT = 'elevator_maint';
    case GAS_CUTOFF = 'gas_cutoff';
    case PROPERTY_NOTICE = 'property_notice';
    case EMERGENCY = 'emergency';
    case MEETING = 'meeting';
    case OTHER = 'other';

    public function label(): string
    {
        return match ($this) {
            self::WATER_CUTOFF => '停水通知',
            self::POWER_CUTOFF => '停电通知',
            self::ELEVATOR_MAINT => '电梯维保',
            self::GAS_CUTOFF => '停气通知',
            self::PROPERTY_NOTICE => '物业公告',
            self::EMERGENCY => '紧急通知',
            self::MEETING => '会议通知',
            self::OTHER => '其他',
        };
    }
}
